//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
import React, { useEffect } from "react";
import SiteSection from "./site-section";
import { isNonEmptyString } from "primeobjects-helper-util";
import { isNumber, map, isArray } from "lodash";
import SiteSimilarSection from "./site-similar";
import SiteTagsSection from "./site-tags";
import { usePrimaryColorName } from "primeobjects-helper-ui";
import { ResizeDetectorDiv } from "primeobjects-ui-web-basic";
import { useState } from "react";
import SiteSwiperSection from "./site-swiper";
export var SitePageHeroArea = function (props) {
    var content = props.content, media = props.media, className = props.className;
    var width = props.width && props.width > 0 ? props.width : 0;
    //16:9 "56.25%"
    //4:3 "75%"
    //3:2 "66%"
    return (React.createElement("div", { className: "w-full pb-8 ".concat(className ? className : ""), style: { width: "".concat(width, "%") } },
        isNonEmptyString(media) && (React.createElement("div", { className: "w-full bg-center bg-cover img", style: {
                backgroundImage: "url(".concat(media, ")"),
                height: 0,
                paddingTop: "66%"
            } })),
        content && (React.createElement("div", { className: "w-full", dangerouslySetInnerHTML: { __html: content } }))));
};
export var SitePageSection = function (props) {
    var solution = props.solution, page = props.page, tagSectionTitle = props.tagSectionTitle, flushCache = props.flushCache, urlTemplate = props.urlTemplate, similarSectionTitle = props.similarSectionTitle, similarSectionAdditionalData = props.similarSectionAdditionalData;
    var colorName = usePrimaryColorName(solution);
    var pageContent = page === null || page === void 0 ? void 0 : page.content;
    var main = pageContent === null || pageContent === void 0 ? void 0 : pageContent.main;
    var leftAreaWidth = main.leftAreaWidthControl &&
        isNumber(main.leftAreaWidth) &&
        main.leftAreaWidth > 0
        ? main.leftAreaWidth
        : 0;
    var rightAreaWidth = main.rightAreaWidthControl &&
        isNumber(main.rightAreaWidth) &&
        main.rightAreaWidth > 0
        ? main.rightAreaWidth
        : 0;
    var maxTagCount = props.maxTagCount ? props.maxTagCount : 100;
    var tags = isArray(page.tags) ? page.tags.slice(0, maxTagCount) : [];
    var _a = useState({
        flexDirection: "row"
    }), mainAreaStyle = _a[0], setMainAreaStyle = _a[1];
    var _b = useState(50), curLeftAreaWidth = _b[0], setCurLeftAreaWidth = _b[1];
    useEffect(function () {
        if (leftAreaWidth == 0 && rightAreaWidth == 0)
            setCurLeftAreaWidth(50);
        if (leftAreaWidth > 0)
            setCurLeftAreaWidth(leftAreaWidth);
        if (rightAreaWidth > 0)
            setCurLeftAreaWidth(100 - rightAreaWidth);
    }, [leftAreaWidth, rightAreaWidth]);
    var onResizeMainArea = function (width) {
        if (width &&
            (width < 650 ||
                width - (curLeftAreaWidth * width) / 100.0 < 300 ||
                (curLeftAreaWidth * width) / 100.0 < 300)) {
            setMainAreaStyle({ flexDirection: "column" });
        }
        else {
            if (leftAreaWidth > 0 || rightAreaWidth > 0) {
                setMainAreaStyle({ flexDirection: "row" });
            }
            else {
                setMainAreaStyle({});
            }
        }
    };
    return (React.createElement(SiteSection, { className: "relative" },
        React.createElement("div", { className: "w-full max-w-7xl mx-auto" },
            React.createElement("div", { className: "flex flex-col lg:flex-row relative w-full" },
                React.createElement("div", { className: "w-full lg:max-w-4xl inline article  mx-auto" },
                    React.createElement(ResizeDetectorDiv, { className: "flex w-full", onDetect: onResizeMainArea, style: mainAreaStyle },
                        main && (React.createElement(SitePageHeroArea, { media: main.leftAreaMedia, content: main.leftAreaContent, width: mainAreaStyle.flexDirection == "column"
                                ? 100
                                : curLeftAreaWidth, className: "pr-8" })),
                        main && (React.createElement(SitePageHeroArea, { media: main.rightAreaMedia, content: main.rightAreaContent, width: mainAreaStyle.flexDirection == "column"
                                ? 100
                                : 100 - curLeftAreaWidth }))),
                    map([1, 2, 3, 4, 5], function (i) {
                        return pageContent &&
                            pageContent["sectionCategoryId_".concat(i)] ? (React.createElement(SiteSwiperSection, { solution: solution, key: i, flushCache: flushCache, cacheKey: "page-swiper", feedType: "categories", feedValue: pageContent["sectionCategoryId_".concat(i)], scope: "global-and-organization", globalOrganizationId: page.organizationId, urlTemplate: urlTemplate, title: pageContent["sectionTitle_".concat(i)], titleSize: "h3" })) : (React.createElement(React.Fragment, { key: i }));
                    }),
                    React.createElement(SiteTagsSection, { data: tags, colorName: colorName, disableShorten: true, wrapperClassName: "xl:hidden mt-6", tagClassName: "mr-4 mb-4 hover:bg-".concat(colorName, "-100"), tagBorderClassName: "border-gray-100 shadow", title: tagSectionTitle, titleSize: "h3" })),
                React.createElement("div", { className: "hidden flex-1 mt-10 xl:flex xl:flex-col lg:border-l lg:pl-10 lg:ml-10 lg:mt-0" },
                    React.createElement(SiteTagsSection, { data: tags, colorName: colorName, disableShorten: true, tagClassName: "mr-4 mb-4 hover:bg-".concat(colorName, "-100"), tagBorderClassName: "border-gray-100 shadow", titleClassName: "xl:hidden", title: tagSectionTitle, titleSize: "h3" }),
                    React.createElement(SiteSimilarSection, { solution: solution, flushCache: flushCache, cacheKey: "page-similar", feedType: "id", feedValue: page.id, scope: "global-and-organization", globalOrganizationId: page.organizationId, additionalData: similarSectionAdditionalData, urlTemplate: urlTemplate, title: similarSectionTitle, titleSize: "h3" }))))));
};
export default SitePageSection;
//# sourceMappingURL=site-page.js.map